@@ -36,8 +36,6 @@
 #include <QProxyStyle>
 #include <QToolButton>
 
-//#include <QMap>
-
 #ifdef PRINTER_ENABLE
 #include <QPrinter>
 #endif
@@ -207,11 +205,8 @@ Variables
   QString man_search_value;
   QString markup_mode;
 
-  //QHash <QString, CMarkupPair*> hs_markup;
   QHash <QString, QString> programs;
   QHash <QString, QString> places_bookmarks;
-//  QHash <int, QString> moon_phase_algos;
-  //QMap <int, QString> moon_phase_algos;
 
 
   QTranslator transl_app;
@@ -246,9 +241,10 @@ Variables
   QString fname_programs;
   QString fname_places_bookmarks;
 
- // QString bookmarks;
   QString fname_crapbook;
+  QString fname_saved_buffers;
   QString fname_tempfile;
+  QString fname_autosaving_files;
   QString fname_tempparamfile;
 
 
@@ -414,6 +410,7 @@ Preferences tab :: Common page UI elements
   QComboBox *cmb_cmdline_default_charset;
   QComboBox *cmb_zip_charset_in;
   QComboBox *cmb_zip_charset_out;
+
   QCheckBox *cb_altmenu;
   QCheckBox *cb_wasd;
 
@@ -425,9 +422,14 @@ Preferences tab :: Common page UI elements
   QCheckBox *cb_session_restore;
   QCheckBox *cb_use_trad_dialogs;
   QCheckBox *cb_use_enca_for_charset_detection;
+
   QCheckBox *cb_override_img_viewer;
   QLineEdit *ed_img_viewer_override;
 
+  QCheckBox *cb_save_buffers;
+  QCheckBox *cb_autosave;
+  QSpinBox *spb_autosave_period;
+
 /*
 =============================================
 Preferences tab :: Functions page UI elements
@@ -655,6 +657,9 @@ File menu callbacks
   void file_set_eol_unix();
   void file_set_eol_win();
   void file_set_eol_mac();
+  void file_set_autosaving_file();
+  void file_unset_autosaving_file();
+
 
 #ifdef PRINTER_ENABLE
   void file_print();
